#include "MK40X256VMD100.h"
#include "kwikstik.h"
#include "Driver_SLCD.h"
#include "Driver_GPIO.h"
#include "Driver_Electrodes.h"
#include <mqx.h>
#include <MK40X256VMD100.h>
#include "graphic.h"
#include "FreTris.h"
#include <event.h>

U08 FStateMachine = FINIT;

extern U08 ElectrodeFlags;
//unsigned char KeyPress;
unsigned int adv_speed = (unsigned int) ADVANCE_NORMAL;
unsigned int adv_delta = (unsigned int) ADVANCE_DELTA;
unsigned int adv_speed_was = (unsigned int) ADVANCE_NORMAL;
unsigned char score8, score64;
unsigned char random_next;
unsigned long numeric_score = 0;


void game_reset(void) {
  
// Just re-initialise the game
        score8 = 0;
        score64 = 0;
        adv_delta = ADVANCE_DELTA;
        adv_speed = ADVANCE_NORMAL;
        adv_speed_was = ADVANCE_NORMAL;
        display_score(score8, score64);
        unghost();
        render();
        random_next = 0;
        numeric_score = 0;
}


void randomise(void){
  
  LPTMR0_CSR |= 0x04;       // Reset on Overflow
  MCG_C1 |= 0x02;           // Enable internal reference clocks
  MCG_C2 |= 0x01;           // Select the fast IRC
  LPTMR0_PSR |= 0x00;       // Fast clock with prescaler disabled
  LPTMR0_CSR |= 0x01;       // Start 'Random' Timer
}

/*************************************************************************
 * Function Name: F_Task - FreTris main function
 *************************************************************************/

void F_Task(uint_32 data)
{
  unsigned char *pt=piece[0];
  unsigned char *ptnext=piece[0];
  unsigned char rotate = 0;
  unsigned char adv_row = 0;
  char column = (char) START_COLUMN;
  unsigned char random = 0;
  unsigned char fullrow = 0x00;
  unsigned char gameover = FALSE;
  unsigned char loopcount = 0;


 pointer electrode_event;

   /* open event connection */
   if (_event_open("event.global",&electrode_event) != MQX_OK)  
   {
      printf("\nOpen Event failed");
      _mqx_exit(0);
   }
   
   
 
  randomise();
  _SLCDModule_TurnOffAllSegments();
  while(1)
  {
   //Wait for Fretris mode to be entered
    while(MainMenuStateMachine!=FRETRIS)
    {
      _time_delay(500);
    }
      

  switch (FStateMachine)
    {
      case FINIT: 
        TSS_SetSystemConfig(System_ElectrodeEnablers_Register,0x3F); 
        _SLCDModule_TurnOnFreescaleSign();
        logo();
        render();
        _time_delay(1000);
    
         FStateMachine = TITLE;
         fretris_logo();
         render();
         ElectrodeFlags = KEYNULL;
         break;
        
      case TITLE:        


        if (ElectrodeFlags & START) {
          gameover = FALSE;
          ElectrodeFlags = KEYNULL; 
          clear_board();
          FStateMachine = HELP;          
        }
        else {
          wait_play();
        }
        break;
     
      case HELP:
         help();
         FStateMachine = PLAY;      
      break;
      
      case PLAY:
        clear_board();
        game_reset();
        ptnext = piece[random_next];
        while(!gameover)
        {
          for (; ; )
          {
            // for each piece
            rotate = 0;
            column = START_COLUMN;
            loopcount = 0;                        // How many rows did we make with this piece??
            adv_speed = adv_speed_was;
            clear_next();
            // The piece in play in now the previous piece.
            random = random_next;
            // Generate a piece for the next go
            random_next = RANDOM;
            // Derive pointers
            ptnext = piece[random_next];
            pt = piece[random+rotate];

            draw(ptnext, 0, START_COLUMN, TRUE);   // Draw the NEXT piece

            if (gameover) break;
            // Now advance the piece 
            for (adv_row=START_ROW; adv_row<STOP_ROW; adv_row++) 
            {
              if (ElectrodeFlags & SPIN ) {
                // We only 'fall off the edge' if we spin on the right-hand side
                rotate++;
                if (rotate == 4) rotate = 0;
                pt = piece[random+rotate];
                column = column - spin_fix(adv_row, column, pt);
              }  // spin
              if (ElectrodeFlags & LEFT ) {
                if (move_allowed(adv_row, column, 0, -1, pt)) column--;
              } 
              if (ElectrodeFlags & START ) {
                gameover = TRUE;
                ElectrodeFlags = KEYNULL;
                break;
              }               
              if (ElectrodeFlags & RIGHT ) {
                if (move_allowed(adv_row, column, 0, 1, pt)) column++;
              }               
              if (ElectrodeFlags & DROP ) {  // fast advance the piece
                // Don't allow adv_speed_was to be overwritten..
                if (adv_speed != ADVANCE_FAST) adv_speed_was = adv_speed;
                adv_speed = ADVANCE_FAST;
              }

              ElectrodeFlags = KEYNULL;
              
              if (move_allowed(adv_row, column, 1, 0, pt)) {            
                draw(pt,adv_row,column, TRUE);
                ghost(pt,column);
                render();
                _time_delay(adv_speed);
                draw(pt,adv_row,column, FALSE);
                unghost();
                render();
              }
              else {            
                draw(pt,adv_row-1,column, TRUE);
                ghost(pt,column);
                render();
                _time_delay(adv_speed);
                if (adv_row == START_ROW) gameover = TRUE;
                adv_row=STOP_ROW;
                adv_speed = adv_speed_was;
              } // if move_allowed
              fullrow = 0;
              
              // Check to see if any rows of 8-pieces have been made...
              while (fullrow != 0xFF){
                fullrow = check_row();
                if (fullrow != 0xFF){
                  // Row number 'fullrow' is complete
                  loopcount++;
                  block8(fullrow);
                  score8++;
                  if (score8 > 7) {
                    score8 = 0;
                    score64++;
                    adv_speed -= ADVANCE_DELTA;
                    adv_speed_was = adv_speed;
                    if (score64 > 7) gameover = TRUE;
                  }
                  display_score(score8, score64);
                  render();
                } // if fullrow
              } // while fullrow
              numeric_score += (10 * loopcount * loopcount * (score64+1) * (score64+1));
              loopcount = 0;
            } // for adv_row
          } // for random
        } // while
        FStateMachine = GAMEOVER;
        game_over(numeric_score);       
        break;

    case GAMEOVER:
      // Just wait for another game to be started, or the EXIT button E4 to be pressed
       if (ElectrodeFlags & DROP) { 
         _SLCDModule_ClearLCD(NO_ARROWS);
         isMarqueeRestart = TRUE;
         MainMenuStateMachine = MAIN;
         ElectrodeFlags = KEYNULL;
        _event_clear(electrode_event, 0x3F);
         FStateMachine = FINIT;

       }

  
       if (ElectrodeFlags & START) { 
        gameover = FALSE;
        ElectrodeFlags = KEYNULL; 
        clear_board();
        FStateMachine = HELP;
      }
      else {
        wait_play();
      }
      
        break;
 
    default:
        break;
    }
    _time_delay(1);  
  }
}


