
#include "Status_Task.h"
#include <io_gpio.h>

void Status_Task(uint_32 data)
{
  Battery_Init();
  InitializeIO();

  while(1)
  {
    USB_Check();
    Battery_Check();
    _time_delay(500);
  }
}

void USB_Check()
{
   //Check if JLINK side plugged in
  if(GetInput(JLINK_INPUT))
  {
    _SLCDModule_TurnOffJLinkSign();
  }
  else
  {
    _SLCDModule_TurnOnJLinkSign();
  }

  //Check if USB side plugged in
  if(GetInput(K40_INPUT))
  {
    _SLCDModule_TurnOffUSBSign();
  }
  else
  {
    _SLCDModule_TurnOnUSBSign();
  }
}


/*
 * Initialize GPIO for detecting USB Power
 */
boolean InitializeIO(void)
{
  //int i;

  const uint_32 input_set[] = {
    USB_JLINK,
    USB_K40,
    GPIO_LIST_END
  };

  /* Open and set port pins as input to read value from switches */
  input_port = fopen("gpio:read", (char_ptr) &input_set);

  return TRUE;
}

/*
 * Get Input from I/O
 */
boolean GetInput(Input_t signal)
{
   boolean  value=FALSE;

   //Set up GPIO structure
   static uint_32 data[] = {
		USB_JLINK,
                USB_K40,
		GPIO_LIST_END
	};

   //Read data from pins
   if (input_port) {
      ioctl(input_port, GPIO_IOCTL_READ,  &data);
   }

   //Parse data recieved
   switch (signal) {
      case JLINK_INPUT:
         value = (data[0] & GPIO_PIN_STATUS)==0;
         break;
     case K40_INPUT:
         value = (data[1] & GPIO_PIN_STATUS)==0;
         break;
   }

   return value;
}


void Battery_Init(void)
{
  _ADC1_Init(16, CHANNEL_A, MODE_8);
  _SLCDModule_TurnOnBatteryOutline();
}

void Battery_Check(void)
{
  char BatteryLevel = _ADC1_Read(16,CHANNEL_A);

  if ((BatteryLevel >= BAT_LOW_LEVEL_THRESHOLD) && (BatteryLevel < BAT_MIDDLE_LEVEL_THRESHOLD))
  {
    _SLCDModule_TurnOnBattery(LOWER_LEVEL);
  }
  else if ((BatteryLevel >= BAT_MIDDLE_LEVEL_THRESHOLD) && (BatteryLevel < BAT_HIGH_LEVEL_THRESHOLD))
  {
    _SLCDModule_TurnOnBattery(MID_LEVEL);
  }
  else if (BatteryLevel >= BAT_HIGH_LEVEL_THRESHOLD)
  {
    _SLCDModule_TurnOnBattery(CHARGED);
  }
  else
  {
    //nothing;
  }
}
