#include "TSI_Task.h"
//#include "Main_Task.c"
#include <event.h>

/* Global variables */
volatile BOOL isElectrodePressed = 0;
volatile BOOL isElectrode0Pressed = 0;
volatile BOOL isElectrode1Pressed = 0;
volatile BOOL isElectrode2Pressed = 0;
volatile BOOL isElectrode3Pressed = 0;
volatile BOOL isElectrode4Pressed = 0;
volatile BOOL isElectrode5Pressed = 0;

extern pointer electrode_event_global;  //declared in mouse.c

/* Pull in global variables from the sound recorder app */
extern BOOL isPlaying;
extern BOOL isRecording;


/*FUNCTION*----------------------------------------------------------------
*
* Function Name  : TSI_Task
* Returned Value : None
* Comments       :
*     The TSI_Task is responsible for monitoring the states of the TSI
*     electrodes. Based on the current state of the electrodes event bits
*     are updated. MQX tasks can poll the event bits or the events can be
*     used to remove tasks from a blocked state.
*
*END*--------------------------------------------------------------------*/
void TSI_Task(uint_32 param)
{
   pointer electrode_event;
   
   /* Set up an event group. This event will be used to store the 
    * state of the TSI electrodes. Then the event states can be used for menu 
    * operation in all of the tasks as needed. 
    */
   //if (_event_create("event.global",&electrode_event) != MQX_OK)  
   if (_event_create("event.global") != MQX_OK)  
   {
      printf("\nMake event failed");
      _mqx_exit(0);
   }   

   /* open event connection */
   if (_event_open("event.global",&electrode_event) != MQX_OK)  
   {
      printf("\nOpen Event failed");
      _mqx_exit(0);
   }
   
   /* assign pointer for electrode event to a global variable (used by USB functions)*/
   electrode_event_global = electrode_event;
   

   while (1) 
   {
      //Wait for initialization to complete
      while(MainMenuStateMachine == INIT)
      {
        _time_delay(500);
      }
     
      /* Skip the electrode check if the sound recorder app is currently
       * playing back. The electrode check routine creates noise in the
       * audio playback otherwise.
       */
      if(isPlaying | isRecording)
      {        
         _time_delay(500);
      }
      else
      {
     
         /* Need a bit of delay here to make sure that the first call to 
          * _Electrodes_Check() has a chance to complete before a second
          * call is made. The code is not re-entrant.
          */
          _time_delay(1);
     
          /* Call the TSS and electrode routines to actually check the current
           * state of the electrodes and update the electrode flags
           */
         _Electrodes_Check();
     
         /* Now that the ElectrodeFlags global variable has been updated with
          * the latest status, we just need to translate that global flag into
          * an MQX event. So that we get an event that can be used to have MQX
          * automatically unblock tasks instead of having to poll the global 
          * variable.
          */
          if (_event_set(electrode_event,ElectrodeFlags) != MQX_OK) 
          {
             printf("\nSet Event failed");
             _mqx_exit(0);
          }
      }          
   }  
}
