#include "Driver_TSI.h"

U08 Electrode0 = 0;       //TSI_CHANNEL9
U08 Electrode1 = 0;       //TSI_CHANNEL12
U16 TSI_Electrode[2] = {0};
U16 TSI_Electrode_Baseline[2] = {0};
U32 DebounceCounter[2] = {DBOUNCE_COUNTS, DBOUNCE_COUNTS};

void _TSIModule_Config(void);
void _TSIModule_SelfCalibration(void);

void _TSIModule_Init(void)
{
  _TSIModule_Config();
  _TSIModule_SelfCalibration();

  START_SCANNING();
  ENABLE_EOS_INT();
  ENABLE_TSI();
}

/********************************************************************************
 *   TSI_Init: Initializes TSI module
 * Notes:
 *    -
 ********************************************************************************/
void _TSIModule_Config(void)
{
  SIM_SCGC5 |= SIM_SCGC5_TSI_MASK   //Turn on TSI's clock
            |  SIM_SCGC5_PORTB_MASK  //Turn on PORTB's clock
            ;
  
  PORTB_PCR0 = PORT_PCR_MUX(0);      //TSI Channel 0
  
  //while(!(TSI0_GENCS & TSI_GENCS_SCNIP_MASK)){}

  TSI0_GENCS = ((TSI_GENCS_NSCN(24)) | (TSI_GENCS_PS(1)));
  TSI0_SCANC = ((TSI_SCANC_EXTCHRG(3)) | (TSI_SCANC_REFCHRG(31)) | (TSI_SCANC_DELVOL(7)) | (TSI_SCANC_SMOD(0)) | (TSI_SCANC_AMPSC(0)));  
  ELECTRODE_ENABLE_REG |= ELECTRODE0_ENABLE; // | ELECTRODE1_ENABLE;

  TSI0_GENCS |= (TSI_GENCS_TSIEN_MASK);  //Enables TSI
}

/********************************************************************************
 *   TSI_SelfCalibration: Simple auto calibration version
 * Notes:
 *    - Very simple, only sums a prefixed amount to the current baseline
 ********************************************************************************/
void _TSIModule_SelfCalibration(void)
{
  U32 delay = 0x1FFFFFF;
  
  TSI0_GENCS |= TSI_GENCS_SWTS_MASK;

  while(!TSI0_GENCS&TSI_GENCS_EOSF_MASK){}

  //_time_delay(1000);
  while(--delay) {}
 
  TSI_Electrode_Baseline[ELECTRODE0] = ELECTRODE0_COUNT;
  ELECTRODE0_OVER_RUN_REG = (U32)((TSI_Electrode_Baseline[ELECTRODE0] + ELECTRODE0_OVER_RUN));
  TSI_Electrode[ELECTRODE0] = (U16)(TSI_Electrode_Baseline[ELECTRODE0] + ELECTRODE0_TOUCH);

 /* TSI_Electrode_Baseline[ELECTRODE1] = ELECTRODE1_COUNT;
  ELECTRODE1_OVER_RUN_REG = (U32)((TSI_Electrode_Baseline[ELECTRODE1] + ELECTRODE1_OVER_RUN));
  TSI_Electrode[ELECTRODE1] = (U16)(TSI_Electrode_Baseline[ELECTRODE1] + ELECTRODE1_TOUCH);*/

  DISABLE_TSI();
}

/********************************************************************************
 *   _TSIModule_Task: TSI Periodic Task
 * Notes:
 *    -
 ********************************************************************************/

U08 _TSIModule_Task(void)
{
  static U08 ValidTouch = 0;
  U16 TouchCounter;

  TSI0_GENCS |= TSI_GENCS_OUTRGF_MASK;
  TSI0_GENCS |= TSI_GENCS_EOSF_MASK;

  /* Process electrode 0 */
  TouchCounter = ELECTRODE0_COUNT;
  if(TouchCounter > TSI_Electrode[ELECTRODE0]) //See if detected a touch
  {
    DebounceCounter[ELECTRODE0]--; //Decrement debounce counter
    if(!DebounceCounter[ELECTRODE0]) //If debounce counter reaches 0....
    {
      ValidTouch |= ((1 << ELECTRODE0)); //Signal that a valid touch has been detected
      DebounceCounter[ELECTRODE0] = DBOUNCE_COUNTS; //Reset debounce counter
    }
  }
  else
  {
    DebounceCounter[ELECTRODE0] = DBOUNCE_COUNTS; //Reset debounce counter
    ValidTouch &= ~(1 << ELECTRODE0);
  }
  /***********************/

  /* Process electrode 1 */
 /* TouchCounter = ELECTRODE1_COUNT;
  if(TouchCounter>TSI_Electrode[ELECTRODE1])
  {    
    DebounceCounter[ELECTRODE1]--;
    if(!DebounceCounter[ELECTRODE1])
    {
      ValidTouch |= ((1 << ELECTRODE1));
      DebounceCounter[ELECTRODE1] = DBOUNCE_COUNTS;
    }
  }
  else
  {
    DebounceCounter[ELECTRODE1] = DBOUNCE_COUNTS;
    ValidTouch &= ~(1 << ELECTRODE1);
  }
  ***********************/

  TSI0_STATUS = 0xFFFFFFFF;
  
  return ValidTouch;
}
